@@ -143,8 +143,8 @@ function task_install_docs_deb {
 # install docs for rpm based systems
 function task_install_docs_rpm {
   if [ -d ext/docs ]; then
-    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-7.18.2"
-    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-7.18.2"
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.8.0"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.8.0"
   fi
 }
 
@@ -189,6 +189,7 @@ function task_install {
     install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
     install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
     install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/prune "${dest_apps_dir}/cli/apps/prune"
     install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
     install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
     install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
@@ -203,6 +204,7 @@ fi
     install -d -m 0755 "${DESTDIR}${rundir}"
     install -d -m 700 "${DESTDIR}${app_logdir}"
     install -d -m 700 "${DESTDIR}/opt/puppetlabs/server/data/puppetserver/jars"
+    install -d -m 700 "${DESTDIR}/opt/puppetlabs/server/data/puppetserver/yaml"
 }
 
 function task_install_redhat {
@@ -359,6 +361,8 @@ function task_postinst_permissions {
     chmod 0755 $rundir
     chown puppet:puppet /opt/puppetlabs/server/data/puppetserver/jars
     chmod 700 /opt/puppetlabs/server/data/puppetserver/jars
+    chown puppet:puppet /opt/puppetlabs/server/data/puppetserver/yaml
+    chmod 700 /opt/puppetlabs/server/data/puppetserver/yaml
 }
 
 # Install logrotate (usually el7, fedora 16 and above)
